@@ -369,7 +369,7 @@ void PlaylistCollection::addFolder()
         for(QStringList::Iterator it = result.addedDirs.begin();
             it != result.addedDirs.end(); it++)
         {
-            m_dirLister.openUrl(KUrl::fromPath(*it), true);
+            m_dirLister.openUrl(KUrl::fromPath(*it), KDirLister::Keep);
             m_folderList.append(*it);
         }
 
@@ -725,10 +725,10 @@ void PlaylistCollection::enableDirWatch(bool enable)
     if(enable) {
         QObject::connect(&m_dirLister, SIGNAL(newItems(const KFileItemList &)),
                 object(), SLOT(slotNewItems(const KFileItemList &)));
-        QObject::connect(&m_dirLister, SIGNAL(refreshItems(const KFileItemList &)),
-                collection, SLOT(slotRefreshItems(const KFileItemList &)));
-        QObject::connect(&m_dirLister, SIGNAL(deleteItem(KFileItem *)),
-                collection, SLOT(slotDeleteItem(KFileItem *)));
+        QObject::connect(&m_dirLister, SIGNAL(refreshItems(const QList<QPair<KFileItem, KFileItem> > &)),
+                collection, SLOT(slotRefreshItems(const QList<QPair<KFileItem, KFileItem> > &)));
+        QObject::connect(&m_dirLister, SIGNAL(deleteItem(const KFileItem &)),
+                collection, SLOT(slotDeleteItem(const KFileItem &)));
     }
 }
 
@@ -828,7 +828,7 @@ void PlaylistCollection::readConfig()
     m_folderList       = config.readEntry("DirectoryList", QStringList());
 
     for(QStringList::ConstIterator it = m_folderList.begin(); it != m_folderList.end(); ++it)
-        m_dirLister.openUrl(*it, true);
+        m_dirLister.openUrl(*it, KDirLister::Keep);
 }
 
 void PlaylistCollection::saveConfig()
